# Keeper Secrets Manager Helper

The Keeper Secrets Manager helper for creating and managing records. To be used with keeper-secrets-manager-core.

For more information see our official documentation page https://docs.keeper.io/secrets-manager/secrets-manager
